Skip to main contentModule port
Source - SiblingExpansion
- Describes how to find sibling files that belong to the same logical module/package.
Used by import resolution to expand candidate search scope.
- ConfigStore
- Shared config operations used by multiple modules.
- DiffStore
- Operations needed by the diff module (working.rs, since.rs, session.rs).
- ExportStore
- Operations needed by the export module.
- FileDiscovery
- Abstraction over file discovery (directory walking with ignore rules).
- LanguageParser
- Trait for language-specific parsing.
- LanguageRegistry
- Registry that provides language parsers and resolvers.
- LanguageResolver
- Trait for language-specific import/module resolution.
- QueryStore
- Read-only operations for querying the index.
- ScanStore
- Storage operations needed by the scan pipeline.
- SymbolLookup
- Shared read-only symbol/file lookup operations.
- VcsProvider
- Abstraction over VCS operations needed by the diff module.